package com.tsiwebserver.mapper;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.ibatis.annotations.Mapper;

@Mapper
public interface StatisticsMapper {
	List<HashMap<String, Object>> getSearchDailyInvoke(Map<String, Object> list);
	List<HashMap<String, Object>> getSearchMonthlyInvoke(Map<String, Object> list);
	
	//systemResource
	List<HashMap<String, Object>> systemResourceMonthlyData(Map<String, Object> list);
	List<HashMap<String, Object>> systemResourceDailyData(Map<String, Object> list);
	
	//신호상태수집정보
	List<HashMap<String, Object>> signalStatusGatherMonthlyData(Map<String, Object> list);
	List<HashMap<String, Object>> signalStatusGatherDailyData(Map<String, Object> list);
	
	//신호상태발송정보
	List<HashMap<String, Object>> signalStatusSendMonthlyData(Map<String, Object> list);
	List<HashMap<String, Object>> signalStatusSendDailyData(Map<String, Object> list);
}
